@@ -1,8 +1,6 @@
-######################################################################
-# UMIT - Private University for Health Sciences,
-#        Medical Informatics and Technology
-#        Institute of Psychology
-#        Statistics and Psychometrics Working Group
+##############################################################################
+# UMIT Tirol -  Private University for Health Sciences and Health Technology
+#   Institute of Psychology, Statistics and Psychometrics Working Group
 #
 # post_hocChange
 #
@@ -14,7 +12,7 @@
 # probability of error of first kind alpha
 #
 # Licensed under the GNU General Public License Version 3 (June 2007)
-# copyright (c) 2021, Last Modified 2/09/2024
+# copyright (c) 2025, Last Modified 2/01/2025
 ######################################################################
 #' Power analysis of tests in context of measurement of change using LLTM
 #'
@@ -33,9 +31,9 @@
 #'More details about the distributions of the test statistics and the relationship between \eqn{\lambda}, power, and
 #'sample size can be found in Draxler and Alexandrowicz (2015).
 #'
-#'In particular, let \eqn{q_{\alpha}} be the \eqn{1- \alpha} quantile of the central \eqn{\chi^2} distribution with df = 1. Then,
+#'In particular, let \eqn{q_{1- \alpha}} be the \eqn{1- \alpha} quantile of the central \eqn{\chi^2} distribution with df = 1. Then,
 #'
-#'\deqn{power = 1 - F_{df, \lambda} (q_{\alpha}),}
+#'\deqn{power = 1 - F_{df, \lambda} (q_{1- \alpha}),}
 #'
 #'where \eqn{F_{df, \lambda}} is the cumulative distribution function of the noncentral \eqn{\chi^2} distribution with
 #'\eqn{df = 1} and \eqn{\lambda} equal to the observed value of the test statistic.
@@ -44,16 +42,16 @@
 #' @param data Data matrix as required for function \code{\link{change_test}}.
 #' @param alpha Probability of error of first kind.
 #'
-#'@return A list of results.
-#' \item{test}{A numeric vector of Wald (W), likelihood ratio (LR), Rao score (RS), and gradient (GR)  test statistics.}
-#'  \item{power}{Posthoc power value for each test.}
-#'  \item{observed deviation}{CML estimate of shift parameter expressing observed deviation from hypothesis to be tested.}
-#'  \item{person score distribution}{Relative frequencies of person scores. Uninformative scores, i.e., minimum and maximum score,
-#'  are omitted. Note that the person score distribution does also have an influence on the power of the tests.}
-#'  \item{degrees of freedom}{Degrees of freedom \eqn{df}.}
-#'  \item{noncentrality parameter}{Noncentrality parameter \eqn{\lambda} of \eqn{\chi^2} distribution from which power is determined.
-#'  It equals observed value of test statistic.}
-#'  \item{call}{The matched call.}
+#' @return A list of results of class \code{tcl_post_hoc}.
+#' \item{test}{A numeric vector of Wald (W), likelihood ratio (LR), Rao score (RS), and gradient (GR) test statistics.}
+#' \item{power}{Posthoc power value for each test.}
+#' \item{dev_obs}{CML estimate of shift parameter expressing observed deviation from the hypothesis to be tested.}
+#' \item{score_dist}{Relative frequencies of person scores. Uninformative scores, i.e., minimum and maximum scores,
+#' are omitted. Note that the person score distribution also influences the power of the tests.}
+#' \item{df}{Degrees of freedom \eqn{df}.}
+#' \item{ncp}{Noncentrality parameter \eqn{\lambda} of \eqn{\chi^2} distribution from which power is determined.
+#' It equals the observed value of the test statistic.}
+#' \item{call}{The matched call.}
 #'
 #' @references{
 #'  Draxler, C., & Alexandrowicz, R. W. (2015). Sample size determination within the scope of conditional
@@ -99,18 +97,18 @@
 #'#     W    LR    RS    GR
 #'# 0.880 0.886 0.884 0.888
 #'#
-#'# $`observed deviation (estimate of shift parameter)`
+#'# $dev_obs #`observed deviation (estimate of shift parameter)`
 #'# [1] 0.504
 #'#
-#'# $`person score distribution`
+#'# $score_dist #`person score distribution`
 #'#
 #'#     1     2     3     4     5     6     7
 #'# 0.047 0.047 0.236 0.277 0.236 0.108 0.047
 #'#
-#'# $`degrees of freedom`
+#'# $df #`degrees of freedom`
 #'# [1] 1
 #'#
-#'# $`noncentrality parameter`
+#'# $ncp # `noncentrality parameter`
 #'#     W     LR     RS     GR
 #'# 9.822 10.021  9.955 10.088
 #'#
@@ -137,16 +135,28 @@ post_hocChange <- function(data, alpha = 0.05){
   est <- eRm::LLTM(X = data, mpoints = 2,se = TRUE, sum0 = FALSE) # unrestricted CML estimates of eta Parameters
   dev_obs <- unname(est$etapar[ncol(data)/2])
 
-  vstats <- change_test(X = data)$test[c(4,2,3,1)] # W, LR, RS, GR test
+  vstats <- change_test(data = data)$test[c(4,2,3,1)] # W, LR, RS, GR test
 
   res <- lapply(vstats, subfunc)
 
-  results <- list(  'test' = round(vstats, digits = 3),
-                    'power' = do.call(c, res),
-                    'observed deviation (estimate of shift parameter)' = round(dev_obs, digits = 3),
-                    'person score distribution' = round(t/sum(t), digits = 3),
-                    'degrees of freedom' = 1,
-                    'noncentrality parameter' = round(vstats, digits = 3),
-                    "call" = call)
+  # results <- list(  'test' = round(vstats, digits = 3),
+  #                   'power' = do.call(c, res),
+  #                   'observed deviation (estimate of shift parameter)' = round(dev_obs, digits = 3),
+  #                   'person score distribution' = round(t/sum(t), digits = 3),
+  #                   'degrees of freedom' = 1,
+  #                   'noncentrality parameter' = round(vstats, digits = 3),
+  #                   "call" = call)
+  results <- structure(
+    list(
+      "test" = round(vstats, digits = 3),
+      "power" = do.call(c, res),
+      "dev_obs" = round(dev_obs, digits = 3),
+      "score_dist" = round(t / sum(t), digits = 3),
+      "df" = 1,
+      "ncp" = round(vstats, digits = 3),
+      "call" = call
+    ),
+    class = "tcl_post_hoc"
+  )
   return(results)
 }
