@@ -1,8 +1,6 @@
-######################################################################
-# UMIT - Private University for Health Sciences,
-#        Medical Informatics and Technology
-#        Institute of Psychology
-#        Statistics and Psychometrics Working Group
+##############################################################################
+# UMIT Tirol -  Private University for Health Sciences and Health Technology
+#   Institute of Psychology, Statistics and Psychometrics Working Group
 #
 # post_hocPCM
 #
@@ -12,7 +10,7 @@
 # RS and GR given data and probability of error of first kind alpha.
 #
 # Licensed under the GNU General Public License Version 3 (June 2007)
-# copyright (c) 2021, Last Modified 2/9/2024
+# copyright (c) 2025, Last Modified 2/1/2025
 ######################################################################
 #' Power analysis of tests of invariance of item parameters between two groups of
 #' persons in partial credit model
@@ -32,35 +30,35 @@
 #' can be determined from \eqn{\lambda}. More details about the distributions of the test statistics and the
 #' relationship between \eqn{\lambda}, power, and sample size can be found in Draxler and Alexandrowicz (2015).
 #'
-#' In particular, let \eqn{q_{\alpha}} be the \eqn{1- \alpha} quantile of the central \eqn{\chi^2} distribution
+#' In particular, let \eqn{q_{1- \alpha}} be the \eqn{1- \alpha} quantile of the central \eqn{\chi^2} distribution
 #' with \eqn{df} equal to the number of free item-category parameters. Then,
 #'
-#' \deqn{power = 1 - F_{df, \lambda} (q_{\alpha}),}
+#' \deqn{power = 1 - F_{df, \lambda} (q_{1- \alpha}),}
 #'
 #' where \eqn{F_{df, \lambda}} is the cumulative distribution function of the noncentral \eqn{\chi^2}
 #' distribution with \eqn{df} equal to the number of free item-category parameters and \eqn{\lambda} equal to the
 #' observed value of the test statistic.
 #'
 #' @param data Data matrix with item responses (in ordered categories starting from 0).
-#' @param x A numeric vector of length equal to number of persons that contains zeros and ones indicating group membership of the persons.
+#' @param splitcr A numeric vector of length equal to number of persons that contains zeros and ones indicating group membership of the persons.
 #' @param alpha Probability of error of first kind.
 #'
-#'@return A list of results.
-#'  \item{test}{A numeric vector of Wald (W), likelihood ratio (LR), Rao score (RS), and gradient (GR)  test statistics.}
-#'  \item{power}{Post hoc power value for each test.}
-#'  \item{observed global deviation}{Observed global deviation from hypothesis to be tested represented by a single number.
-#'  It is obtained by dividing the test statistic by the informative sample size.
-#'  The latter does not include persons with minimum or maximum person score.}
-#'  \item{observed local deviation}{CML estimates of free item-category parameters in both groups of persons representing observed deviation
-#'  from hypothesis to be tested locally per item and response category.}
-#'  \item{person score distribution in group 1}{Relative frequencies of person scores in group 1. Uninformative scores, i.e., minimum and maximum score, are omitted.
-#'  Note that the person score distribution does also have an influence on the power of the tests.}
-#'  \item{person score distribution in group 2}{Relative frequencies of person scores in group 2. Uninformative scores, i.e., minimum and maximum score, are omitted.
-#'  Note that the person score distribution does also have an influence on the power of the tests.}
-#'  \item{degrees of freedom}{Degrees of freedom \eqn{df}.}
-#'  \item{noncentrality parameter}{Noncentrality parameter \eqn{\lambda} of \eqn{\chi^2} distribution from which power is determined.
-#'  It equals observed value of test statistic.}
-#'  \item{call}{The matched call.}
+#' @return A list of results of class \code{tcl_post_hoc}.
+#' \item{test}{A numeric vector of Wald (W), likelihood ratio (LR), Rao score (RS), and gradient (GR) test statistics.}
+#' \item{power}{Post hoc power value for each test.}
+#' \item{dev_global}{Observed global deviation from the hypothesis to be tested, represented by a single number.
+#' It is obtained by dividing the test statistic by the informative sample size,
+#' which excludes persons with minimum or maximum person scores.}
+#' \item{dev_local}{CML estimates of free item-category parameters in both groups of persons, representing observed
+#' deviation from the hypothesis to be tested locally per item and response category.}
+#' \item{score_dist_group1}{Relative frequencies of person scores in group 1. Uninformative scores, i.e., minimum and
+#' maximum scores, are omitted. Note that the person score distribution also influences the power of the tests.}
+#' \item{score_dist_group2}{Relative frequencies of person scores in group 2. Uninformative scores, i.e., minimum and
+#' maximum scores, are omitted. Note that the person score distribution also influences the power of the tests.}
+#' \item{df}{Degrees of freedom \eqn{df}.}
+#' \item{ncp}{Noncentrality parameter \eqn{\lambda} of the \eqn{\chi^2} distribution from which power is determined.
+#' It equals the observed value of the test statistic.}
+#' \item{call}{The matched call.}
 #'
 #'
 #' @references{
@@ -69,8 +67,8 @@
 #' Draxler, C., & Alexandrowicz, R. W. (2015). Sample Size Determination Within the Scope of Conditional Maximum Likelihood Estimation
 #' with Special Focus on Testing the Rasch Model. Psychometrika, 80(4), 897–919.
 #'
-#' Draxler, C., Kurz, A., & Lemonte, A. J. (2020). The Gradient Test and its Finite Sample Size Properties in a Conditional Maximum Likelihood
-#' and Psychometric Modeling Context. Communications in Statistics-Simulation and Computation, 1-19.
+#' Draxler, C., Kurz, A., & Lemonte, A. J. (2022). The gradient test and its finite sample size properties in a conditional
+#' maximum likelihood and psychometric modeling context. Communications in Statistics-Simulation and Computation, 51(6), 3185-3203.
 #'
 #' Glas, C. A. W., & Verhelst, N. D. (1995a). Testing the Rasch Model. In G. H. Fischer & I. W. Molenaar (Eds.),
 #' Rasch Models: Foundations, Recent Developments, and Applications (pp. 69–95). New York: Springer.
@@ -90,7 +88,7 @@
 #' n <- nrow(y) # sample size
 #' x <- c( rep(0,n/2), rep(1,n/2) ) # binary covariate
 #'
-#' res <- post_hocPCM(data = y, x = x, alpha = 0.05)
+#' res <- post_hocPCM(data = y, splitcr = x, alpha = 0.05)
 #'
 #'# > res
 #'# $test
@@ -101,29 +99,29 @@
 #'#     W    LR    RS    GR
 #'# 0.683 0.702 0.694 0.709
 #'#
-#'# $`observed global deviation`
+#'# $dev_global #`observed global deviation`
 #'#     W    LR    RS    GR
 #'# 0.045 0.046 0.045 0.047
 #'#
-#'# $`observed local deviation`
+#'# $ dev_local #`observed local deviation`
 #'#        I1-C2 I2-C1 I2-C2  I3-C1  I3-C2  I4-C1  I4-C2
 #'# group1 2.556 0.503 2.573 -2.573 -2.160 -1.272 -0.683
 #'# group2 2.246 0.878 3.135 -1.852 -0.824 -0.494  0.941
 #'#
-#'# $`person score distribution in group 1`
+#'# $score_dist_group1 #`person score distribution in group 1`
 #'#
 #'#     1     2     3     4     5     6     7
 #'# 0.016 0.097 0.137 0.347 0.121 0.169 0.113
 #'#
-#'# $`person score distribution in group 2`
+#'# $score_dist_group2 #`person score distribution in group 2`
 #'#
 #'#     1     2     3     4     5     6     7
 #'# 0.015 0.083 0.136 0.280 0.152 0.227 0.106
 #'#
-#'# $`degrees of freedom`
+#'# $df #`degrees of freedom`
 #'# [1] 7
 #'#
-#'# $`noncentrality parameter`
+#'# $ncp #`noncentrality parameter`
 #'#      W     LR     RS     GR
 #'# 11.395 11.818 11.628 11.978
 #'#
@@ -131,7 +129,7 @@
 #'# post_hocPCM(alpha = 0.05, data = y, x = x)
 #' }
 
-post_hocPCM <- function(data, x, alpha = 0.05){
+post_hocPCM <- function(data, splitcr, alpha = 0.05){
 
   subfunc <- function(stats) {
     e <- stats/(sum(t1) + sum(t2))
@@ -143,6 +141,7 @@ post_hocPCM <- function(data, x, alpha = 0.05){
     }
 
   call <- match.call()
+  x <- splitcr
 
   e <- tcl_splitcr(X = data, splitcr = x, model = "PCM")
   y1 <- e$X.list[[1]]
@@ -164,14 +163,28 @@ post_hocPCM <- function(data, x, alpha = 0.05){
 
   res <- lapply(vstats, subfunc)
 
-  results <- list(  'test' = round(vstats, digits = 3),
-                    'power' = unlist(do.call(cbind, res)[1,]),
-                    'observed global deviation' = unlist(do.call(cbind, res)[2,]),
-                    'observed local deviation' = round( rbind("group1" = r1$coefficients, "group2" = r2$coefficients), digits = 3 ),
-                    'person score distribution in group 1' = round(t1/sum(t1), digits = 3),
-                    'person score distribution in group 2' = round(t2/sum(t2), digits = 3),
-                    'degrees of freedom' = df,
-                    'noncentrality parameter' = round(vstats, digits = 3),
-                    "call" = call)
+  # results <- list(  'test' = round(vstats, digits = 3),
+  #                   'power' = unlist(do.call(cbind, res)[1,]),
+  #                   'observed global deviation' = unlist(do.call(cbind, res)[2,]),
+  #                   'observed local deviation' = round( rbind("group1" = r1$coefficients, "group2" = r2$coefficients), digits = 3 ),
+  #                   'person score distribution in group 1' = round(t1/sum(t1), digits = 3),
+  #                   'person score distribution in group 2' = round(t2/sum(t2), digits = 3),
+  #                   'degrees of freedom' = df,
+  #                   'noncentrality parameter' = round(vstats, digits = 3),
+  #                   "call" = call)
+  results <- structure(
+    list(
+      test = round(vstats, digits = 3),
+      power = unlist(do.call(cbind, res)[1, ]),
+      dev_global = unlist(do.call(cbind, res)[2, ]),
+      dev_local = round(rbind(group1 = r1$coefficients, group2 = r2$coefficients), digits = 3),
+      score_dist_group1 = round(t1 / sum(t1), digits = 3),
+      score_dist_group2 = round(t2 / sum(t2), digits = 3),
+      df = df,
+      ncp = round(vstats, digits = 3),
+      call = call
+    ),
+    class = "tcl_post_hoc"
+  )
   return(results)
 }
