@@ -1,8 +1,6 @@
-######################################################################
-# UMIT - Private University for Health Sciences,
-#        Medical Informatics and Technology
-#        Institute of Psychology
-#        Statistics and Psychometrics Working Group
+##############################################################################
+# UMIT Tirol -  Private University for Health Sciences and Health Technology
+#   Institute of Psychology, Statistics and Psychometrics Working Group
 #
 # post_hocRM
 #
@@ -12,7 +10,7 @@
 # given data and probability of error of first kind alpha
 #
 # Licensed under the GNU General Public License Version 3 (June 2007)
-# copyright (c) 2021, Last Modified 2/9/2024
+# copyright (c) 2025, Last Modified 2/1/2025
 ######################################################################
 #' Power analysis of tests of invariance of item parameters between two groups of persons in binary Rasch model
 #'
@@ -30,34 +28,34 @@
 #' determined from \eqn{\lambda}. More details about the distributions of the test statistics and the relationship
 #' between \eqn{\lambda}, power, and sample size can be found in Draxler and Alexandrowicz (2015).
 #'
-#' In particular, let \eqn{q_{\alpha}} be the \eqn{1- \alpha} quantile of the central \eqn{\chi^2} distribution
+#' In particular, let \eqn{q_{1- \alpha}} be the \eqn{1- \alpha} quantile of the central \eqn{\chi^2} distribution
 #' with df equal to the number of items minus 1. Then,
 #'
-#' \deqn{power = 1 - F_{df, \lambda} (q_{\alpha}),}
+#' \deqn{power = 1 - F_{df, \lambda} (q_{1- \alpha}),}
 #'
 #' where \eqn{F_{df, \lambda}} is the cumulative distribution function of the noncentral \eqn{\chi^2} distribution
 #' with \eqn{df} equal to the number of items reduced by 1 and \eqn{\lambda} equal to the observed value of the test statistic.
 #'
 #' @param data Binary data matrix.
-#' @param x A numeric vector of length equal to number of persons containing zeros and ones indicating group membership of the persons.
+#' @param splitcr A numeric vector of length equal to number of persons containing zeros and ones indicating group membership of the persons.
 #' @param alpha Probability of error of first kind.
 #'
-#'@return A list of results.
+#'@return A list of results of class \code{tcl_post_hoc}.
 #'  \item{test}{A numeric vector of Wald (W), likelihood ratio (LR), Rao score (RS), and gradient (GR) test statistics.}
 #'  \item{power}{Post hoc power value for each test.}
-#'  \item{global deviation}{Observed global deviation from hypothesis to be tested represented by a single number.
+#'  \item{dev_global}{Observed global deviation from hypothesis to be tested represented by a single number.
 #'  It is obtained by dividing the test statistic by the informative sample size. The latter does not include persons
 #'  with minimum or maximum person score. }
-#'  \item{local deviation}{CML estimates of free item parameters in both groups of persons (first item parameter set
+#'  \item{dev_local}{CML estimates of free item parameters in both groups of persons (first item parameter set
 #'  to 0 in both groups) representing observed deviation from hypothesis to be tested locally per item.}
-#'  \item{person score distribution in group 1}{Relative frequencies of person scores in group 1. Uninformative scores,
+#'  \item{score_dist_group1}{Relative frequencies of person scores in group 1. Uninformative scores,
 #'  i.e., minimum and maximum score, are omitted. Note that the person score distribution does also have an influence on
 #'  the power of the tests.}
-#'  \item{person score distribution in group 2}{Relative frequencies of person scores in group 2. Uninformative scores,
+#'  \item{score_dist_group2}{Relative frequencies of person scores in group 2. Uninformative scores,
 #'  i.e., minimum and maximum score, are omitted. Note that the person score distribution does also have an influence on
 #'  the power of the tests.}
-#'  \item{degrees of freedom}{Degrees of freedom \eqn{df}.}
-#'  \item{noncentrality parameter}{Noncentrality parameter \eqn{\lambda} of \eqn{\chi^2} distribution from which power is determined.
+#'  \item{df}{Degrees of freedom \eqn{df}.}
+#'  \item{ncp}{Noncentrality parameter \eqn{\lambda} of \eqn{\chi^2} distribution from which power is determined.
 #'  It equals observed value of test statistic.}
 #'  \item{call}{The matched call.}
 #'
@@ -89,7 +87,7 @@
 #' n <- nrow(y) # sample size
 #' x <- c( rep(0,n/2), rep(1,n/2) ) # binary covariate
 #'
-#' res <-  post_hocRM(data = y, x = x, alpha = 0.05)
+#' res <-  post_hocRM(data = y, splitcr = x, alpha = 0.05)
 #'
 #'# > res
 #'# $test
@@ -100,11 +98,11 @@
 #'#     W    LR    RS    GR
 #'# 0.890 0.900 0.899 0.903
 #'#
-#'# $`observed global deviation`
+#'# $dev_global #`observed global deviation`
 #'#     W    LR    RS    GR
 #'# 0.292 0.300 0.299 0.302
 #'#
-#'# $`observed local deviation`
+#'# $dev_local #`observed local deviation`
 #'#           I2    I3    I4    I5    I6    I7    I8    I9   I10   I11
 #'# group1 1.039 0.693 2.790 2.404 1.129 1.039 0.864 1.039 2.790 2.244
 #'# group2 2.006 0.945 2.006 3.157 1.834 0.690 0.822 1.061 2.689 2.260
@@ -115,7 +113,7 @@
 #'# group1 0.438 0.608 1.617 3.038 0.438 1.617 2.100 2.583 0.864
 #'# group2 0.822 1.275 1.565 2.175 0.207 1.746 1.746 2.260 0.822
 #'#
-#'# $`person score distribution in group 1`
+#'# $score_dist_group1 #`person score distribution in group 1`
 #'#
 #'#    1    2    3    4    5    6    7    8    9   10   11   12   13
 #'# 0.02 0.02 0.02 0.06 0.02 0.10 0.10 0.06 0.10 0.12 0.08 0.12 0.12
@@ -124,7 +122,7 @@
 #'#   27   28   29
 #'# 0.00 0.00 0.00
 #'#
-#'# $`person score distribution in group 2`
+#'# $score_dist_group2 #`person score distribution in group 2`
 #'#
 #'#    1    2    3    4    5    6    7    8    9   10   11   12   13
 #'# 0.00 0.00 0.00 0.00 0.00 0.00 0.00 0.00 0.00 0.00 0.00 0.00 0.00
@@ -133,10 +131,10 @@
 #'#   27   28   29
 #'# 0.00 0.00 0.00
 #'#
-#'# $`degrees of freedom`
+#'# $df #`degrees of freedom`
 #'# [1] 29
 #'#
-#'# $`noncentrality parameter`
+#'# $ncp #`noncentrality parameter`
 #'#      W     LR     RS     GR
 #'# 29.241 29.981 29.937 30.238
 #'#
@@ -147,7 +145,7 @@
 
 
 
-post_hocRM <- function(data, x, alpha = 0.05){
+post_hocRM <- function(data, splitcr, alpha = 0.05){
 
   subfunc <- function(stats) {
     e <- stats/(sum(t1) + sum(t2))
@@ -158,6 +156,7 @@ post_hocRM <- function(data, x, alpha = 0.05){
                 'observed global deviation' = round(e, digits = 3)))
   }
   call <- match.call()
+  x <- splitcr
 
   # Check for inappropriate response patterns within subgroups
   e <- tcl_splitcr(X = data, splitcr = x, model = "RM")
@@ -177,14 +176,28 @@ post_hocRM <- function(data, x, alpha = 0.05){
 
   res <- lapply(vstats, subfunc)
 
-  results <- list(  'test' = round(vstats, digits = 3),
-                    'power' = unlist(do.call(cbind, res)[1,]),
-                    'observed global deviation' = unlist(do.call(cbind, res)[2,]),
-                    'observed local deviation' = round( rbind("group1" = r1$coefficients, "group2" = r2$coefficients), digits = 3 ),
-                    'person score distribution in group 1' = round(t1/sum(t1), digits = 3),
-                    'person score distribution in group 2' = round(t2/sum(t2), digits = 3),
-                    'degrees of freedom' = df,
-                    'noncentrality parameter' = round(vstats, digits = 3),
-                    "call" = call)
+  # results <- list(  'test' = round(vstats, digits = 3),
+  #                   'power' = unlist(do.call(cbind, res)[1,]),
+  #                   'observed global deviation' = unlist(do.call(cbind, res)[2,]),
+  #                   'observed local deviation' = round( rbind("group1" = r1$coefficients, "group2" = r2$coefficients), digits = 3 ),
+  #                   'person score distribution in group 1' = round(t1/sum(t1), digits = 3),
+  #                   'person score distribution in group 2' = round(t2/sum(t2), digits = 3),
+  #                   'degrees of freedom' = df,
+  #                   'noncentrality parameter' = round(vstats, digits = 3),
+  #                   "call" = call)
+  results <- structure(
+    list(
+      test = round(vstats, digits = 3),
+      power = unlist(do.call(cbind, res)[1, ]),
+      dev_global = unlist(do.call(cbind, res)[2, ]),
+      dev_local = round(rbind(group1 = r1$coefficients, group2 = r2$coefficients), digits = 3),
+      score_dist_group1 = round(t1 / sum(t1), digits = 3),
+      score_dist_group2 = round(t2 / sum(t2), digits = 3),
+      df = df,
+      ncp = round(vstats, digits = 3),
+      call = call
+      ),
+    class = "tcl_post_hoc"
+  )
   return(results)
 }
