@@ -1,8 +1,6 @@
-######################################################################
-# UMIT - Private University for Health Sciences,
-#        Medical Informatics and Technology
-#        Institute of Psychology
-#        Statistics and Psychometrics Working Group
+##############################################################################
+# UMIT Tirol -  Private University for Health Sciences and Health Technology
+#   Institute of Psychology, Statistics and Psychometrics Working Group
 #
 # powerPCM
 #
@@ -15,7 +13,7 @@
 # where one assumes all items presented to all persons.
 #
 # Licensed under the GNU General Public License Version 3 (June 2007)
-# copyright (c) 2021, Last Modified 2/9/2024
+# copyright (c) 2025, Last Modified 10/2/2025
 ######################################################################
 #' Power analysis of tests of invariance of item parameters between two groups
 #' of persons in partial credit model
@@ -67,11 +65,11 @@
 #'parameter \eqn{\lambda} can then be expressed by
 #'\eqn{\lambda = n_{total}* (n_{infsim} / n_{totalsim}) * e}, where \eqn{n_{totalsim}} denotes
 #'the total number of persons in the simulated data and \eqn{n_{infsim} / n_{totalsim}} is
-#'the proportion of informative persons in the sim. data. Let \eqn{q_{\alpha}} be the
+#'the proportion of informative persons in the sim. data. Let \eqn{q_{1- \alpha}} be the
 #'\eqn{1 - \alpha} quantile of the central \eqn{\chi^2} distribution with df equal to the
 #'number of free item-category parameters. Then,
 #'
-#'\deqn{power = 1 - F_{df, \lambda} (q_{\alpha}),}
+#'\deqn{power = 1 - F_{df, \lambda} (q_{1- \alpha}),}
 #'
 #'where \eqn{F_{df, \lambda}} is the cumulative distribution function of the noncentral
 #'\eqn{\chi^2} distribution with \eqn{df} equal to the number of free item-category parameters
@@ -122,6 +120,8 @@
 #'procedure. It is called Monte Carlo error of power.
 #'
 #' @param n_total Total sample size for which power shall be determined.
+#' @param obj An object of class `LR` from the `eRm` package. If provided, `local_dev` is extracted automatically.
+#' If missing, `local_dev` must be set manually.
 #' @param local_dev A list consisting of two lists. One list refers to group 1, the other to group 2.
 #' Each of the two lists contains a numeric vector per item, i.e., each list contains as many vectors as items.
 #' Each vector contains the free item-cat. parameters of the respective item. The number of free item-cat.
@@ -134,21 +134,21 @@
 #' By default \eqn{10^6} parameters are drawn at random from the standard normal distribution. The larger
 #' this number the more accurate are the computations. See Details.
 #'
-#'@return A list of results.
+#'@return A list of results of class \code{tcl_power}.
 #'  \item{power}{Power value for each test.}
-#'  \item{MC error of power}{Monte Carlo error of power computation for each test.}
-#'  \item{global deviation}{Global deviation computed from simulated data for each test. See Details.}
-#'  \item{local deviation}{CML estimates of free item-category parameters in both groups of persons
+#'  \item{mc_error_power}{Monte Carlo error of power computation for each test.}
+#'  \item{dev_global}{Global deviation computed from simulated data for each test. See Details.}
+#'  \item{dev_local}{CML estimates of free item-category parameters in both groups of persons
 #'  obtained from the simulated data expressing a deviation from the hypothesis to be tested locally
 #'  per item and response category.}
-#'  \item{person score distribution in group 1}{Relative frequencies of person scores in group 1 observed in
+#'  \item{score_dist_group1}{Relative frequencies of person scores in group 1 observed in
 #'  simulated data. Uninformative scores, i.e., minimum and maximum score, are omitted.
 #'  Note that the person score distribution does also have an influence on the power of the tests.}
-#'  \item{person score distribution in group 2}{Relative frequencies of person scores in group 2 observed in
+#'  \item{score_dist_group2}{Relative frequencies of person scores in group 2 observed in
 #'  simulated data. Uninformative scores, i.e., minimum and maximum score, are omitted.
 #'  Note that the person score distribution does also have an influence on the power of the tests.}
-#'  \item{degrees of freedom}{Degrees of freedom \eqn{df}.}
-#'  \item{noncentrality parameter}{Noncentrality parameter \eqn{\lambda} of \eqn{\chi^2} distribution from which power is determined.}
+#'  \item{df}{Degrees of freedom \eqn{df}.}
+#'  \item{ncp}{Noncentrality parameter \eqn{\lambda} of \eqn{\chi^2} distribution from which power is determined.}
 #'  \item{call}{The matched call.}
 #'
 #' @references{
@@ -157,8 +157,8 @@
 #' Draxler, C., & Alexandrowicz, R. W. (2015). Sample Size Determination Within the Scope of Conditional Maximum Likelihood Estimation
 #' with Special Focus on Testing the Rasch Model. Psychometrika, 80(4), 897–919.
 #'
-#' Draxler, C., Kurz, A., & Lemonte, A. J. (2020). The Gradient Test and its Finite Sample Size Properties in a Conditional Maximum Likelihood
-#' and Psychometric Modeling Context. Communications in Statistics-Simulation and Computation, 1-19.
+#' Draxler, C., Kurz, A., & Lemonte, A. J. (2022). The gradient test and its finite sample size properties in a conditional
+#' maximum likelihood and psychometric modeling context. Communications in Statistics-Simulation and Computation, 51(6), 3185-3203.
 #'
 #' Glas, C. A. W., & Verhelst, N. D. (1995a). Testing the Rasch Model. In G. H. Fischer & I. W. Molenaar (Eds.),
 #' Rasch Models: Foundations, Recent Developments, and Applications (pp. 69–95). New York: Springer.
@@ -173,7 +173,7 @@
 #' @seealso \code{\link{sa_sizePCM}}, and \code{\link{post_hocPCM}}.
 #' @examples
 #' \dontrun{
-#' # Numerical example
+#' #Numerical example of power analysis for the PCM model
 #'
 #' # free item-category parameters for group 1 and 2  with 5 items, with 3 categories each
 #' local_dev <-  list (  list(c( 0, 0), c( -1, 0), c( 0, 0),  c( 1, 0), c( 1, 0.5)) ,
@@ -186,42 +186,79 @@
 #'#     W    LR    RS    GR
 #'# 0.863 0.885 0.876 0.892
 #'#
-#'# $`MC error of power`
+#'# $mc_error_power #`MC error of power`
 #'#     W    LR    RS    GR
 #'# 0.002 0.002 0.002 0.002
 #'#
-#'# $`global deviation`
+#'# $dev_global #`global deviation`
 #'#     W    LR    RS    GR
 #'# 0.102 0.107 0.105 0.109
 #'#
-#'# $`local deviation`
+#'# $dev_local #`local deviation`
 #'#         I1-C2  I2-C1  I2-C2  I3-C1  I3-C2 I4-C1 I4-C2  I5-C1  I5-C2
 #'# group1  0.002 -0.997 -0.993  0.006  0.012 1.002 1.007  1.006  1.508
 #'# group2 -0.007 -1.005 -1.007 -0.006 -0.009 0.993 0.984 -0.006 -0.510
 #'#
-#'# $`person score distribution in group 1`
+#'# $score_dist_group1 # `person score distribution in group 1`
 #'#
 #'#     1     2     3     4     5     6     7     8     9
 #'# 0.112 0.130 0.131 0.129 0.122 0.114 0.101 0.091 0.070
 #'#
-#'# $`person score distribution in group 2`
+#'# $score_dist_group2 #`person score distribution in group 2`
 #'#
 #'#     1     2     3     4     5     6     7     8     9
 #'# 0.091 0.108 0.117 0.122 0.122 0.121 0.115 0.110 0.093
 #'#
-#'# $`degrees of freedom`
+#'# $df #`degrees of freedom`
 #'# [1] 9
 #'#
-#'# $`noncentrality parameter`
+#'# $ncp #`noncentrality parameter`
 #'#      W     LR     RS     GR
 #'# 18.003 19.024 18.596 19.403
 #'#
 #'# $call
 #'# powerPCM(alpha = 0.05, n_total = 200, persons1 = rnorm(10^6),
 #'#          persons2 = rnorm(10^6), local_dev = local_dev)
+#'
+#'
+#'# Numerical example of power analysis for the PCM model
+#'# extracting local_dev from an eRm object
+#'ppar = rnorm(10000)
+#'ipar = list(-2:2,-2:2+0.2,-2:2-0.3,-2:2+0.1,-2:2-0.8)
+#'dat2 = psychotools::rpcm(theta = ppar, delta = ipar)
+#'
+#'mod2 = PCM(dat2$data)
+#'obj2 = eRm::LRtest(mod2)
+#'
+#'res <- powerPCM(n_total = 200, obj = obj2)
 #' }
-
 powerPCM <- function(n_total,
+                     obj = NULL,
+                     local_dev = NULL,
+                     alpha = 0.05,
+                     persons1 = rnorm(10^6),
+                     persons2 = rnorm(10^6)) {
+
+  # If obj is provided, extract local_dev
+  if (!is.null(obj)) {
+    stopifnot("obj must be of eRm class 'LR'" = inherits(obj, "LR"))
+    local_dev <- get_eRm_arg(obj, arg = "local_dev")
+    message("Extracted local_dev from obj.")
+  }
+
+  # If local_dev is still NULL, stop with an error
+  if (is.null(local_dev)) {
+    stop("Either 'obj' (of eRm class 'LR') or 'local_dev' must be provided.")
+  }
+
+  # Call sample size function with extracted or provided local_dev
+  results <- powerPCM_compute(n_total,local_dev, alpha, persons1, persons2)
+  return(results)
+}
+
+
+#' @noRd
+powerPCM_compute <- function(n_total,
                      local_dev,
                      alpha = 0.05,
                      persons1 = rnorm(10^6),
@@ -270,14 +307,20 @@ powerPCM <- function(n_total,
 
   res <- lapply(vstats, subfunc)
 
-  results <- list(  'power' = unlist(do.call(cbind, res)[1,]),
-                    'MC error of power' = unlist(do.call(cbind, res)[2,]),
-                    'global deviation' = unlist(do.call(cbind, res)[3,]),
-                    'local deviation' = round(rbind("group1" = r1$coefficients, "group2" = r2$coefficients), digits = 3),
-                    'person score distribution in group 1' = round(t1/sum(t1), digits = 3),
-                    'person score distribution in group 2' = round(t2/sum(t2), digits = 3),
-                    'degrees of freedom' = df,
-                    'noncentrality parameter' = unlist(do.call(cbind, res)[4,]),
-                    "call" = call)
+  results <- structure(
+    list(
+      power = unlist(do.call(cbind, res)[1, ]),
+      mc_error_power = unlist(do.call(cbind, res)[2, ]),
+      dev_global = unlist(do.call(cbind, res)[3, ]),
+      dev_local = round(rbind(group1 = r1$coefficients, group2 = r2$coefficients), digits = 3),
+      score_dist_g1 = round(t1 / sum(t1), digits = 3),
+      score_dist_g2 = round(t2 / sum(t2), digits = 3),
+      df = df,
+      ncp = unlist(do.call(cbind, res)[4, ]),
+      call = call
+    ),
+    class = "tcl_power"
+  )
+
   return(results)
 }
